@@ -38,8 +38,7 @@ class CategoryEditDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit CategoryEditDialog(CalendarSupport::CategoryConfig *categoryConfig,
-                                QWidget *parent = nullptr);
+    explicit CategoryEditDialog(CalendarSupport::CategoryConfig *categoryConfig, QWidget *parent = nullptr);
 
     ~CategoryEditDialog();
 
@@ -67,8 +66,8 @@ protected:
 
 private:
     void deleteItem(QTreeWidgetItem *item, QList<QTreeWidgetItem *> &to_remove);
-    CalendarSupport::CategoryConfig *mCategoryConfig;
-    Ui::CategoryEditDialog_base *mWidgets;
+    CalendarSupport::CategoryConfig *mCategoryConfig = nullptr;
+    Ui::CategoryEditDialog_base *mWidgets = nullptr;
 };
 }
 
